@@ -1,5 +1,5 @@
 <?php
-//VERSION=0.6
+//VERSION=0.7
 $info = get_token_info();
 
 $user = $info['email'];
@@ -86,7 +86,7 @@ function valid_token($t)
 {
 	$len = strlen($t);
 	if ($len > 128) return false;
-	if ($len < 100) return true;
+	if ($len < 100) return false;
 	return preg_match("/^([a-zA-Z0-9])+$/", $t);
 }
 
